#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ansi-terminal-types
version:              1.1
visibility:           public
id:                   ansi-terminal-types-1.1-GKFVltpZJlz5wFhwe1CQA
key:                  ansi-terminal-types-1.1-GKFVltpZJlz5wFhwe1CQA
license:              BSD-3-Clause
maintainer:
    Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>

author:               Max Bolingbroke
homepage:             https://github.com/UnkindPartition/ansi-terminal
synopsis:             Types and functions used to represent SGR aspects
description:
    The \'\''ANSI\'\'' standards refer to the visual style of
    displaying characters as their \'\''graphic rendition\'\''. The
    \'\''ANSI\'\'' codes to establish the graphic rendition for
    subsequent text are referred to as SELECT GRAPHIC RENDITION
    (SGR). This package exposes modules that export types and
    functions used to represent SGR aspects.

category:             User Interfaces
abi:                  782b1e083fd4c5bf08c9694def9213ba
exposed:              True
exposed-modules:      System.Console.ANSI.Types
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ansi-terminal-types-1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ansi-terminal-types-1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ansi-terminal-types-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-terminal-types
hs-libraries:         HSansi-terminal-types-1.1-GKFVltpZJlz5wFhwe1CQA
depends:              base-4.18.2.1 colour-2.3.7-LvQs8ewmnio1Lssq54nOFL
haddock-interfaces:
    /usr/share/doc/haskell-ansi-terminal-types/html/ansi-terminal-types.haddock

haddock-html:         /usr/share/doc/haskell-ansi-terminal-types/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

